@@ -1,6 +1,6 @@
 import time
 import datetime
-import math_utils
+import zcc_utils.math_utils as math_utils
 
 
 def second_to_minute(second: int):
